@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2003-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -680,7 +680,7 @@ class Wicked_Driver_Sql extends Wicked_Driver
         }
 
         /* Copy the old version into the page history. */
-        Horde::logMessage('Page ' . $pagename . ' saved with user agent ' . $GLOBALS['browser']->getAgentString(), 'DEBUG');
+        Horde::log('Page ' . $pagename . ' saved with user agent ' . $GLOBALS['browser']->getAgentString(), 'DEBUG');
 
         $author = $GLOBALS['registry']->getAuth();
         if ($author === false) {
