@@ -1,6 +1,6 @@
 <?php
 /**
- * Copyright 2003-2013 Horde LLC (http://www.horde.org/)
+ * Copyright 2003-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -199,7 +199,7 @@ class Wicked_Page
      * @return Wicked_Page  The current page.
      * @throws Wicked_Exception
      */
-    public function getCurrentPage()
+    static public function getCurrentPage()
     {
         return Wicked_Page::getPage(rtrim(Horde_Util::getFormData('page'), '/'),
                                     Horde_Util::getFormData('version'),
@@ -430,8 +430,10 @@ class Wicked_Page
 
     /**
      * Renders this page in diff mode.
+     *
+     * @param string $version  The version to diff this page against.
      */
-    public function diff()
+    public function diff($version)
     {
         throw new Wicked_Exception(_("Unsupported"));
     }
@@ -445,7 +447,7 @@ class Wicked_Page
         $view_url = Wicked::url('%s')
             ->setRaw(true)
             ->add('referrer', $this->pageName());
-        $view_url = str_replace(array(urlencode('%s'), urlencode('/')), array('%s', '%' . urlencode('/')), $view_url);
+        $view_url = str_replace(urlencode('%s'), '%s', $view_url);
 
         /* Create format-specific Text_Wiki object */
         $class = 'Text_Wiki_' . $GLOBALS['conf']['wicked']['format'];
@@ -634,6 +636,11 @@ class Wicked_Page
         return null;
     }
 
+    public function changeLog()
+    {
+        return null;
+    }
+
     public function pageUrl($linkpage = null, $actionId = null)
     {
         $params = array('page' => $this->pageName());
